@@ -56,29 +56,41 @@ Web::MREST - Minimalistic REST server
 
 =head1 VERSION
 
-Version 0.252
+Version 0.256
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.256';
 
 
 =head2 Development status
 
-L<Web::MREST> is currently in Alpha.
+L<Web::MREST> is currently in "Alpha - feature freeze". There are almost
+certainly bugs lurking in the code, but all features have been implemented.
 
 
 
 
 =head1 SYNOPSIS
 
-Server startup script does this:
+To take this module for a spin, execute this command:
 
+    $ mrest Web-MREST Web::MREST::Dispatch
 
-Run server startup script to start server:
+Leave this running, and from another console start the command-line client:
 
+    $ mrest-cli
 
-Issue a HTTP request:
+In the CLI client, type e.g.
+
+    Web::MREST::CLI::Parser> get /
+
+A 'GET' request will be sent for the root resource and the CLI client
+will display a representation of the response.
+
+A similar result can be obtained using C<curl>:
+
+     curl -v http://localhost:5000/ -X GET -H "Content-Type: application/json"
 
 
 
@@ -104,17 +116,27 @@ L<Web::MREST::WebServicesIntro>.
 
 =head1 RFC2616 AS A STATE MACHINE
 
+RFC2616 is, of course, the HTTP 1.1 standard - not a state machine. But
+the authors of "Web Machine" (which was originally implemented in Erlang) had a
+neat idea to represent it as a state machine and use this to implement a server
+for providing web services.
+
+L<Web::Machine> is, of course, the Perl port of Web Machine.
+
 L<Web::MREST> relies on L<Web::Machine> to implement RFC2616. L<Web::MREST>
 can be thought of as an additional abstraction layer over L<Web::Machine>.
 
-L<Web::Machine> is not a server by itself: it does not listen on a port.
-Instead, it uses L<Plack> to interface with a L<PSGI>-compliant web server.
+By itself, L<Web::Machine> is not a server. It does not listen on a port, for
+example. Instead, it is designed to work (via L<Plack>) with a
+L<PSGI>-compliant web server.
 
-When a request comes in, it goes through a state machine, which the
-L<Web::Machine> authors refer to as "the FSM." The state machine is basically
-a flow-chart. At each "decision node" of the flow-chart - where flow can go in
-one of two directions - L<Web::Machine> calls the method corresponding to that
-node. Each node is designated by a letter and a number: e.g. F7, O18, etc.
+The web server hands incoming requests over to L<Web::Machine>, which runs the
+requests through its state machine. (The L<Web::Machine> authors refer to the
+state machine as "the FSM.") The best way to grasp the state machine is to
+envision it as a flow-chart. At each "decision node" of the flow-chart - where
+flow can go in one of two directions - L<Web::Machine> calls the method
+corresponding to that node. Each node is designated by a letter and a number:
+e.g. F7, O18, etc.
 
 The flow-chart implemented by the FSM can be found L<here|http://...> - you are
 encouraged to have that open for reference while reading this documentation
@@ -272,7 +294,7 @@ start to look for the method.
 
 If the method is not found at the lowest level, Perl follows the chain of
 inheritance "upward". The highest level, L<Plack::Component>, is shown only for
-completeness - L<Web::Machine::Resource> and L<Web::Machine::Entity> implement
+completeness - L<Web::MREST::Resource> and L<Web::MREST::Entity> implement
 all the methods that your resource module might (or should) want to override.
 
 Readers who are not well-versed in writing Perl applications that use
@@ -382,21 +404,25 @@ and L<App::CELL::Guide>.
 
 =head2 Error statuses
 
-Obviously, L<Web::Machine> always tries to return the proper HTTP status
-code in the response. There are times, however, when the application developer
-may wish for the ability to override this. For example, she may want to catch
-exceptions and expose them to the client with C<500 - Internal Error>. 
+L<Web::Machine> always tries to return the proper HTTP status code in the
+response. The application developer will likely need to "force" a code in
+certain cases. For example, the request may be "malformed" in a way that is
+not discoverable until the handler runs. Or, caught exceptions may need to be
+exposed to the client with C<500 - Internal Error>. 
 
 Also, the RFC says
 
     . . . the server SHOULD include an entity containing an explanation of the
     error situation, and whether it is a temporary or permanent condition.
 
-and L<Web::Machine> does not provide any special mechanism for providing such
-explanations or indicating whether the error is temporary or permanent. What
-L<web::Machine> does provide is a mechanism for "forcing" an arbitrary status
-code (e.g. C<404 - Not Found>) by returning a scalar reference. This mechanism
-has two disadvantages:
+Clearly, then, a mechanism is needed for providing such explanations and
+indicating whether the error is temporary or permanent. And that mechanism
+should enable an arbitrary status code to be declared.
+
+By itself, L<Web::Machine> does not really provide such a mechanism.  What it
+does provide is a mechanism for "forcing" an arbitrary status code (e.g. C<404
+- Not Found>) by returning a scalar reference. This mechanism has two
+disadvantages:
 
 =over
 
@@ -405,14 +431,14 @@ has two disadvantages:
 I wanted a way to "declare" a status code at any point and be certain that
 L<Web::Machine> won't change it later on.
 
-=item there is no way to provide an explanation of the error
+=item there is no obvious way to provide an explanation of the error
 
 L<Web::Machine> considers this an implementation detail.
 
 =back
 
-Hence, L<Web::MREST> offers the C<mrest_declare_status> method, which is 
-documented in L<Web::MREST::Resource>.
+Hence, L<Web::MREST> provides the C<mrest_declare_status> method. To learn
+how to call it and how it works, see L<Web::MREST::Resource>.
 
 
 
@@ -747,12 +773,13 @@ paragraphs describe L<Web::MREST>'s approach.
 By the time control reaches this method, the request URI has already been
 matched to a resource definition. So the resource handler is known.  Since we
 have no other way of knowing, we ask the resource itself, by calling the
-handler with the scalar value C<'resource_exists'> as the sole argument.
+handler with the scalar value C<1> (i.e. the numeral 1) as the sole argument.
+This handler call is referred to as the "first pass".
 
 How the handler is implemented does not concern us. We only ask that it return
 a boolean value (true or false) when called with this argument. If the return
 value from the handler is true, we can assume that the handler will be called
-again in the response generation phase (see below).
+again (second pass) in the response generation phase - read on.
 
 
 =head2 Part Four (generation of response entity)
@@ -790,8 +817,10 @@ This method is the one we mean when we refer to the "response generator".
 =item 2. Response generator method call
 
 Second, the response generator is called (from C<o18> in
-L<Web::Machine::FSM::States>). It returns either a scalar value (JSON)
-reference to a scalar (e.g. \400, interpreted as an HTTP response code).
+L<Web::Machine::FSM::States>). It is expected to always return an
+L<App::CELL::Status> object. If an error condition is detected, the
+handler should declare it using C<< $self->mrest_declare_status >>
+and then return a "non_ok" status.
 
 =back
 
@@ -1318,6 +1347,8 @@ files.
 
 A reference to a hash containing meta parameters to be loaded.
 
+=back
+
 =cut 
 
 sub init {
