@@ -51,11 +51,11 @@ Web::MREST::CLI::Parser - Parser for MREST command line client
 
 =head1 VERSION
 
-Version 0.252
+Version 0.256
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.256';
 our $anything = qr/^.+$/i;
 
 
@@ -140,6 +140,14 @@ sub parse_tokens {
     # second token represents the resource class ( top-level, employee, priv, etc.)
     if ( @$pre == 1 ) {
 
+        #
+        # root resource
+        #
+        if ( $token eq '/' ) {
+            die send_req( $method, '/' );
+        }
+
+        #
         #
         # top-level resource: handle it here
         #
