@@ -50,7 +50,7 @@ use HTTP::Request::Common qw( GET PUT POST DELETE );
 use JSON;
 use LWP::UserAgent;
 use URI::Escape;
-use Web::MREST::Util qw( $JSON );
+use Web::MREST::Util qw( $JSON normalize_filespec );
 
 my %sh;
 
@@ -65,11 +65,11 @@ Web::MREST::CLI::UserAgent - HTTP user agent for command-line client
 
 =head1 VERSION
 
-Version 0.252
+Version 0.256
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.256';
 
 
 
@@ -122,7 +122,7 @@ Initialize the LWP::UserAgent singleton object.
 =cut
 
 sub init_ua {
-    $ua->cookie_jar( { file => $site->MREST_CLI_COOKIE_JAR } );
+    $ua->cookie_jar( { file => normalize_filespec( $site->MREST_CLI_COOKIE_JAR ) } );
     return;
 }
 
