@@ -59,11 +59,11 @@ App::MREST::Dispatch - Resource handlers
 
 =head1 VERSION
 
-Version 0.252
+Version 0.256
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.256';
 
 
 
@@ -340,7 +340,6 @@ sub _first_pass_always_exists {
 
     if ( $pass == 1 ) {
         $log->debug( "Resource handler first pass, resource always exists" );
-        $self->context->{'resource_exists'} = 1;
         return 1;
     }
     return 0;
@@ -415,7 +414,6 @@ sub handler_docu {
     if ( ref( $def ) ne 'HASH' ) {
         $self->mrest_declare_status( 'code' => 404, 'explanation' => 'Undefined resource' );
         $log->debug( "Resource not defined: " . Dumper( $docu_resource ) );
-        $self->context->{'resource_exists'} = 0;
         return $CELL->status_not_ok;
     }
 
@@ -504,7 +502,6 @@ sub handler_param {
         $bool = $param_obj->exists( $param );
         $bool = $bool ? 1 : 0;
         $self->context->{'stash'}->{'param_value'} = $param_obj->get( $param ) if $bool;
-        $self->context->{'resource_exists'} = $bool;
         return $bool;
     }
 
@@ -555,7 +552,6 @@ sub handler_noop {
         'children' => $def->{'children'},
     };
     return $CELL->status_ok( 'DISPATCH_NOOP',
-        resource_exists => 1,
         payload => $pl
     );
 }
@@ -569,14 +565,14 @@ handling.
 =cut
 
 sub handler_test {
-    my $self = shift;
+    my ( $self, $pass ) = @_;
 
     my $method = $self->context->{'method'};
     my $mapping = $self->context->{'mapping'};
     my $specs = $self->context->{'mapping'}->{'specs'} if $mapping;
 
     # first pass
-    if ( not exists $self->context->{'resource_exists'} ) {
+    if ( $pass == 1 ) {
         my $re = 0;
         if ( not defined $specs ) {
             $log->debug( "handler_test: \$specs is missing and the resource exists" );
@@ -593,7 +589,6 @@ sub handler_test {
                 }
             }
         }
-        $self->context->{'resource_exists'} = $re;
         return $re;
     }
 
@@ -652,7 +647,6 @@ sub _test_put {
         # pretend that a new resource was created
         $status = $CELL->status_ok( 'TEST_PUT_NEW_RESOURCE_CREATED' );
     }
-    $status->{'resource_exists'} = $bool;
     $status->payload( 'DUMMY' );
     return $status;
 }
@@ -667,13 +661,11 @@ sub _test_delete {
         $status = $CELL->status_ok( 'TEST_RESOURCE_DELETED' );
     } else {
         # resource didn't exist
-        $status = $CELL->status_not_ok( 'TEST_NON_EXISTENT_RESOURCE', args => [ 'DELETE' ],
-            'resource_exists' => 0 );
+        $status = $CELL->status_not_ok( 'TEST_NON_EXISTENT_RESOURCE', args => [ 'DELETE' ], );
         # we have to force 404 here - due to how Web::Machine handles DELETE 
         $self->mrest_declare_status( 'code' => 404, 
             explanation => 'Request to delete non-existent resource; nothing to do' );
     }
-    $status->{'resource_exists'} = $bool;
     $status->payload( 'DUMMY' );
     return $status;
 }
