@@ -72,11 +72,11 @@ App::MREST::Resource - HTTP request/response cycle
 
 =head1 VERSION
 
-Version 0.252
+Version 0.256
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.256';
 
 
 
@@ -962,13 +962,17 @@ sub process_post {
     # Web::Machine is patched we have no other way of knowing the request
     # handler's name so we have to hard-code it like this.
     #$self->_load_request_entity;
-    my $status = $self->mrest_process_request;
-    return $status if ref( $status ) eq 'SCALAR';
-
-    return \200 if $self->context->{'handler_status'}->ok;
-
+    #my $status = $self->mrest_process_request;
+    #return $status if ref( $status ) eq 'SCALAR';
+    #
+    #return \200 if $self->context->{'handler_status'}->ok;
+    #
     # if the handler status is not ok, there SHOULD be a declared status
-    return $self->mrest_declared_status_code || \500;
+    #return $self->mrest_declared_status_code || \500;
+
+    my $status = $self->mrest_process_request;
+    $log->debug( "Handler returned: " . Dumper( $status ) );
+    return $status;
 }
 
 
