@@ -40,8 +40,8 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
-use Web::MREST;
 use Data::Dumper;
+use File::HomeDir;
 use HTTP::Request;
 use JSON;
 use Log::Any::Adapter;
@@ -51,6 +51,7 @@ use Test::JSON;
 use Test::More;
 use Try::Tiny;
 use Web::Machine;
+use Web::MREST;
 
 
 
@@ -64,11 +65,11 @@ Web::MREST::Test - Test helper functions
 
 =head1 VERSION
 
-Version 0.252
+Version 0.256
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.256';
 
 
 
@@ -132,7 +133,7 @@ sub initialize_unit {
         : ();
 
     # zero logfile and tell Log::Any to log to it
-    my $log_file_spec = $ENV{'HOME'} . "/mrest.log";
+    my $log_file_spec = File::HomeDir->my_home . "/mrest.log";
     unlink $log_file_spec;
     Log::Any::Adapter->set( 'File', $log_file_spec );
     $log->init( ident => 'MREST_UNIT_TEST' );
